@@ -566,42 +566,6 @@ class SeleniumDriverCore(object):
         else:
             raise Exception(res['message'])
 
-    def _match_bounding_box_to_selenium_element(self, bounding_box, multiplier=1):
-        """
-            We have to ba hacky about this becasue Selenium does not let us click by coordinates.
-            We retrieve all elements, compute the IOU between the bounding_box and all the elements and pick the best match.
-        """
-        # Adapt box to local coordinates
-        new_box = {'x': bounding_box['x'] / multiplier, 'y': bounding_box['y'] / multiplier,
-                   'width': bounding_box['width'] / multiplier, 'height': bounding_box['height'] / multiplier}
-        # Get all elements
-        elements = self.driver.find_elements(By.XPATH, "//*")
-        # Compute IOU
-        iou_scores = []
-        for element in elements:
-            try:
-                iou_scores.append(self._iou_boxes(new_box, element.rect))
-            except StaleElementReferenceException:
-                iou_scores.append(0)
-        composite = sorted(zip(iou_scores, elements), reverse=True, key=lambda x: x[0])
-        # Pick the best match
-        """
-        We have to be smart about element selection here because of clicks being intercepted and what not, so we basically
-        examine the elements in order of decreasing score, where score > 0. As long as the center of the box is within the elements,
-        they are a valid candidate. If none of them is of type input, we pick the one with maxIOU, otherwise we pick the input type,
-        which is 90% of test cases.
-        """
-        composite = filter(lambda x: x[0] > 0, composite)
-        composite = list(filter(lambda x: self._center_hit(new_box, x[1].rect), composite))
-
-        if len(composite) == 0:
-            raise NoElementFoundException('Could not find any web element under the center of the bounding box')
-        else:
-            for score, element in composite:
-                if (element.tag_name == 'input' or element.tag_name == 'button') and score > composite[0][0] * 0.9:
-                    return element
-            return composite[0][1]
-
     def _iou_boxes(self, box1, box2):
         return self._iou(box1['x'], box1['y'], box1['width'], box1['height'], box2['x'], box2['y'], box2['width'],
                          box2['height'])
